@@ -1,5 +1,5 @@
 package Thread::Csp;
-$Thread::Csp::VERSION = '0.002';
+$Thread::Csp::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -24,14 +24,14 @@ Thread::Csp - Communicating sequential processes threading for Perl
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
  # in script.pl
  use Thread::Csp;
  my $input = Thread::Csp::Channel->new;
- my $output = Thread::Csp::cHannel->new;
+ my $output = Thread::Csp::Channel->new;
  Thread::Csp->spawn('Module', 'Module::function', $input, $output);
 
  while (<>) {
